@@ -405,6 +405,41 @@ class Column(Node):
         return t
 
 
+class Notification(Node):
+
+    """MIB notification node. This class represent a notification."""
+
+    @property
+    def objects(self):
+        """Get objects for a notification.
+
+        :return: The list of objects (as :class:`Column`,
+            :class:`Node` or :class:`Scalar` instances) of the notification.
+        """
+        child = self.node
+        lindex = []
+        element = _smi.smiGetFirstElement(child)
+        while element != ffi.NULL:
+            nelement = _smi.smiGetElementNode(element)
+            if nelement == ffi.NULL:
+                raise SMIException("cannot get object "
+                                   "associated with {0}".format(
+                                       ffi.string(self.node.name)))
+            if nelement.nodekind == _smi.SMI_NODEKIND_COLUMN:
+                lindex.append(Column(nelement))
+            elif nelement.nodekind == _smi.SMI_NODEKIND_NODE:
+                lindex.append(Node(nelement))
+            elif nelement.nodekind == _smi.SMI_NODEKIND_SCALAR:
+                lindex.append(Scalar(nelement))
+            else:
+                raise SMIException("object {0} for {1} is "
+                                   "not a node".format(
+                                       ffi.string(nelement.name),
+                                       ffi.string(self.node.name)))
+            element = _smi.smiGetNextElement(element)
+        return lindex
+
+
 _lastError = None
 
 
@@ -478,6 +513,7 @@ def _kind2object(kind):
         _smi.SMI_NODEKIND_NODE: Node,
         _smi.SMI_NODEKIND_SCALAR: Scalar,
         _smi.SMI_NODEKIND_TABLE: Table,
+        _smi.SMI_NODEKIND_NOTIFICATION: Notification,
         _smi.SMI_NODEKIND_COLUMN: Column
     }.get(kind, Node)
 
@@ -591,6 +627,16 @@ def getColumns(mib):
     return _get_kind(mib, _smi.SMI_NODEKIND_COLUMN)
 
 
+def getNotifications(mib):
+    """Return all notifications from a givem MIB.
+
+    :param mib: The MIB name
+    :return: The list of all notifications for the MIB
+    :rtype: list of :class:`Notification` instances
+    """
+    return _get_kind(mib, _smi.SMI_NODEKIND_NOTIFICATION)
+
+
 def load(mib):
     """Load a MIB into the library.
 
