@@ -57,6 +57,7 @@ class SNMPBadValue(SNMPException):
 class SNMPReadOnly(SNMPException):
     pass
 
+
 # Dynamically build remaining (v2) exceptions
 for name, obj in inspect.getmembers(error):
     if name.endswith("Error") and \
@@ -84,6 +85,7 @@ class Session(object):
                  authpassword=None,
                  privprotocol=None,
                  privpassword=None,
+                 contextname=None,
                  bulk=40,
                  none=False):
         """Create a new SNMP session.
@@ -115,6 +117,8 @@ class Session(object):
         :type privprotocol: None or str
         :param privpassword: Privacy password if privacy protocol is
             not `None`.
+        :type contextname: str
+        :param contextname: Context name for SNMPv3 messages.
         :type privpassword: str
         :param bulk: Max repetition value for `GETBULK` requests. Set
             to `0` to disable.
@@ -128,10 +132,12 @@ class Session(object):
         self._none = none
         if version == 3:
             self._cmdgen = cmdgen.CommandGenerator()
+            self._contextname = contextname
         else:
             if not hasattr(self._tls, "cmdgen"):
                 self._tls.cmdgen = cmdgen.CommandGenerator()
             self._cmdgen = self._tls.cmdgen
+            self._contextname = None
         if version == 1 and none:
             raise ValueError("None-GET requests not compatible with SNMPv1")
 
@@ -214,11 +220,11 @@ class Session(object):
     def _check_exception(self, value):
         """Check if the given ASN1 value is an exception"""
         if isinstance(value, rfc1905.NoSuchObject):
-            raise SNMPNoSuchObject("No such object was found")  # nopep8
+            raise SNMPNoSuchObject("No such object was found")  # noqa: F821
         if isinstance(value, rfc1905.NoSuchInstance):
-            raise SNMPNoSuchInstance("No such instance exists")  # nopep8
+            raise SNMPNoSuchInstance("No such instance exists")  # noqa: F821
         if isinstance(value, rfc1905.EndOfMibView):
-            raise SNMPEndOfMibView("End of MIB was reached")  # nopep8
+            raise SNMPEndOfMibView("End of MIB was reached")  # noqa: F821
 
     def _convert(self, value):
         """Convert a PySNMP value to some native Python type"""
@@ -251,8 +257,11 @@ class Session(object):
 
     def _op(self, cmd, *oids):
         """Apply an SNMP operation"""
+        kwargs = {}
+        if self._contextname:
+            kwargs['contextName'] = rfc1902.OctetString(self._contextname)
         errorIndication, errorStatus, errorIndex, varBinds = cmd(
-            self._auth, self._transport, *oids)
+            self._auth, self._transport, *oids, **kwargs)
         if errorIndication:
             self._check_exception(errorIndication)
             raise SNMPException(str(errorIndication))
