@@ -435,7 +435,3 @@ class TestSnmpTransports(unittest.TestCase):
     def testIpv6(self):
         """Test IPv6 transport"""
         self._test(True, "[::1]")
-
-    def testIpv6WithDNS(self):
-        """Test IPv6 transport with name resolution"""
-        self._test(True, "ip6-localhost")
